@@ -47,12 +47,12 @@ PyObject * IsMember64(PyObject * self, PyObject * args)
     int sizeType1 = (int)NpyItemSize((PyObject *)inArr1);
     int sizeType2 = (int)NpyItemSize((PyObject *)inArr2);
 
-    LOGGING("IsMember32 %s vs %s   size: %d  %d\n", NpyToString(arrayType1), NpyToString(arrayType2), sizeType1, sizeType2);
+    LOGGING("IsMember64 %s vs %s   size: %d  %d\n", NpyToString(arrayType1), NpyToString(arrayType2), sizeType1, sizeType2);
 
     if (arrayType1 != arrayType2)
     {
         // Arguments do not match
-        PyErr_Format(PyExc_ValueError, "IsMember32 needs first arg to match %s vs %s", NpyToString(arrayType1),
+        PyErr_Format(PyExc_ValueError, "IsMember64 needs first arg to match %s vs %s", NpyToString(arrayType1),
                      NpyToString(arrayType2));
         return NULL;
     }
@@ -60,7 +60,7 @@ PyObject * IsMember64(PyObject * self, PyObject * args)
     if (sizeType1 == 0)
     {
         // Weird type
-        PyErr_Format(PyExc_ValueError, "IsMember32 needs a type it understands %s vs %s", NpyToString(arrayType1),
+        PyErr_Format(PyExc_ValueError, "IsMember64 needs a type it understands %s vs %s", NpyToString(arrayType1),
                      NpyToString(arrayType2));
         return NULL;
     }
@@ -68,7 +68,7 @@ PyObject * IsMember64(PyObject * self, PyObject * args)
     if (arrayType1 == NPY_OBJECT)
     {
         PyErr_Format(PyExc_ValueError,
-                     "IsMember32 cannot handle unicode strings, "
+                     "IsMember64 cannot handle unicode strings, "
                      "please convert to np.chararray");
         return NULL;
     }
@@ -90,37 +90,44 @@ PyObject * IsMember64(PyObject * self, PyObject * args)
 
     if (boolArray && indexArray)
     {
-        void * pDataIn1 = PyArray_BYTES(inArr1);
-        void * pDataIn2 = PyArray_BYTES(inArr2);
-        int8_t * pDataOut1 = (int8_t *)PyArray_BYTES(boolArray);
-        int64_t * pDataOut2 = (int64_t *)PyArray_BYTES(indexArray);
-
-        // printf("Size array1: %llu   array2: %llu\n", arraySize1, arraySize2);
-
-        if (arrayType1 >= NPY_STRING)
+        try
         {
-            LOGGING("Calling string!\n");
-            IsMemberHashString64(arraySize1, sizeType1, (const char *)pDataIn1, arraySize2, sizeType2, (const char *)pDataIn2,
-                                 pDataOut2, pDataOut1, HASH_MODE(hashMode), hintSize, arrayType1 == NPY_UNICODE);
-        }
-        else
-        {
-            if (arrayType1 == NPY_FLOAT32 || arrayType1 == NPY_FLOAT64)
+            void * pDataIn1 = PyArray_BYTES(inArr1);
+            void * pDataIn2 = PyArray_BYTES(inArr2);
+            int8_t * pDataOut1 = (int8_t *)PyArray_BYTES(boolArray);
+            int64_t * pDataOut2 = (int64_t *)PyArray_BYTES(indexArray);
+
+            // printf("Size array1: %llu   array2: %llu\n", arraySize1, arraySize2);
+
+            if (arrayType1 >= NPY_STRING)
             {
-                IsMemberHash64(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, pDataOut1, sizeType1 + 100,
-                               HASH_MODE(hashMode), hintSize);
+                LOGGING("Calling string!\n");
+                IsMemberHashString64(arraySize1, sizeType1, (const char *)pDataIn1, arraySize2, sizeType2, (const char *)pDataIn2,
+                                     pDataOut2, pDataOut1, HASH_MODE(hashMode), hintSize, arrayType1 == NPY_UNICODE);
             }
             else
             {
-                IsMemberHash64(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, pDataOut1, sizeType1, HASH_MODE(hashMode),
-                               hintSize);
+                if (arrayType1 == NPY_FLOAT32 || arrayType1 == NPY_FLOAT64)
+                {
+                    IsMemberHash64(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, pDataOut1, sizeType1 + 100,
+                                   HASH_MODE(hashMode), hintSize);
+                }
+                else
+                {
+                    IsMemberHash64(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, pDataOut1, sizeType1,
+                                   HASH_MODE(hashMode), hintSize);
+                }
+
+                PyObject * retObject = Py_BuildValue("(OO)", boolArray, indexArray);
+                Py_DECREF((PyObject *)boolArray);
+                Py_DECREF((PyObject *)indexArray);
+
+                return (PyObject *)retObject;
             }
-
-            PyObject * retObject = Py_BuildValue("(OO)", boolArray, indexArray);
-            Py_DECREF((PyObject *)boolArray);
-            Py_DECREF((PyObject *)indexArray);
-
-            return (PyObject *)retObject;
+        }
+        catch (std::runtime_error const & e)
+        {
+            PyErr_Format(PyExc_RuntimeError, e.what());
         }
     }
     // out of memory
@@ -235,48 +242,56 @@ PyObject * IsMemberCategorical(PyObject * self, PyObject * args)
 
     int64_t missed = 0;
 
-    if (arrayType1 >= NPY_STRING)
+    try
     {
-        LOGGING("Calling string/uni/void!\n");
-        missed = IsMemberCategoricalHashStringPre(&indexArray, inArr1, arraySize1, sizeType1, (const char *)pDataIn1, arraySize2,
-                                                  sizeType2, (const char *)pDataIn2, HASH_MODE(hashMode), hintSize,
-                                                  arrayType1 == NPY_UNICODE);
-    }
-    else if (arrayType1 == NPY_FLOAT32 || arrayType1 == NPY_FLOAT64 || arrayType1 == NPY_LONGDOUBLE)
-    {
-        LOGGING("Calling float!\n");
-        if (arraySize1 < 2100000000)
+        if (arrayType1 >= NPY_STRING)
         {
-            indexArray = AllocateLikeNumpyArray(inArr1, NPY_INT32);
-            int32_t * pDataOut2 = (int32_t *)PyArray_BYTES(indexArray);
-            missed = IsMemberHashCategorical(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, sizeType1 + 100,
-                                             HASH_MODE(hashMode), hintSize);
+            LOGGING("Calling string/uni/void!\n");
+            missed = IsMemberCategoricalHashStringPre(&indexArray, inArr1, arraySize1, sizeType1, (const char *)pDataIn1,
+                                                      arraySize2, sizeType2, (const char *)pDataIn2, HASH_MODE(hashMode), hintSize,
+                                                      arrayType1 == NPY_UNICODE);
+        }
+        else if (arrayType1 == NPY_FLOAT32 || arrayType1 == NPY_FLOAT64 || arrayType1 == NPY_LONGDOUBLE)
+        {
+            LOGGING("Calling float!\n");
+            if (arraySize1 < 2100000000)
+            {
+                indexArray = AllocateLikeNumpyArray(inArr1, NPY_INT32);
+                int32_t * pDataOut2 = (int32_t *)PyArray_BYTES(indexArray);
+                missed = IsMemberHashCategorical(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, sizeType1 + 100,
+                                                 HASH_MODE(hashMode), hintSize);
+            }
+            else
+            {
+                indexArray = AllocateLikeNumpyArray(inArr1, NPY_INT64);
+                int64_t * pDataOut2 = (int64_t *)PyArray_BYTES(indexArray);
+                missed = IsMemberHashCategorical64(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, sizeType1 + 100,
+                                                   HASH_MODE(hashMode), hintSize);
+            }
         }
         else
         {
-            indexArray = AllocateLikeNumpyArray(inArr1, NPY_INT64);
-            int64_t * pDataOut2 = (int64_t *)PyArray_BYTES(indexArray);
-            missed = IsMemberHashCategorical64(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, sizeType1 + 100,
-                                               HASH_MODE(hashMode), hintSize);
+            LOGGING("Calling hash!\n");
+            if (arraySize1 < 2100000000)
+            {
+                indexArray = AllocateLikeNumpyArray(inArr1, NPY_INT32);
+                int32_t * pDataOut2 = (int32_t *)PyArray_BYTES(indexArray);
+                missed = IsMemberHashCategorical(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, sizeType1,
+                                                 HASH_MODE(hashMode), hintSize);
+            }
+            else
+            {
+                indexArray = AllocateLikeNumpyArray(inArr1, NPY_INT64);
+                int64_t * pDataOut2 = (int64_t *)PyArray_BYTES(indexArray);
+                missed = IsMemberHashCategorical64(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, sizeType1,
+                                                   HASH_MODE(hashMode), hintSize);
+            }
         }
     }
-    else
+    catch (std::runtime_error const & e)
     {
-        LOGGING("Calling hash!\n");
-        if (arraySize1 < 2100000000)
-        {
-            indexArray = AllocateLikeNumpyArray(inArr1, NPY_INT32);
-            int32_t * pDataOut2 = (int32_t *)PyArray_BYTES(indexArray);
-            missed = IsMemberHashCategorical(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, sizeType1, HASH_MODE(hashMode),
-                                             hintSize);
-        }
-        else
-        {
-            indexArray = AllocateLikeNumpyArray(inArr1, NPY_INT64);
-            int64_t * pDataOut2 = (int64_t *)PyArray_BYTES(indexArray);
-            missed = IsMemberHashCategorical64(arraySize1, pDataIn1, arraySize2, pDataIn2, pDataOut2, sizeType1,
-                                               HASH_MODE(hashMode), hintSize);
-        }
+        PyErr_Format(PyExc_RuntimeError, e.what());
+        return NULL;
     }
 
     PyObject * retObject = Py_BuildValue("(LO)", missed, indexArray);
